# Geodata 
Geodata supports wildcard searches and phonetic searches from the 20M entry geoname.org database.  

<a name="features"></a>
## Features  
* Rich place name database from geonames.org 
* Wildcard search
* Phonetic search
* Highlights locations in the US and Canada where the event date is before European settlement
  
   
[See User Guide Wiki for details](https://github.com/corb555/Geodata/wiki/User-Guide)
